from typing import List, Optional
from sqlalchemy.orm import Session

from app.models.item import Item
from app.schemas.item import ItemCreate, ItemUpdate
from app.crud.base import CRUDBase

class CRUDItem(CRUDBase[Item, ItemCreate, ItemUpdate]):
    def get_by_name(self, db: Session, *, name: str) -> Optional[Item]:
        """Get an item by name."""
        return db.query(Item).filter(Item.name == name).first()
    
    def get_active(self, db: Session, *, skip: int = 0, limit: int = 100) -> List[Item]:
        """Get active items with pagination."""
        return db.query(Item).filter(Item.is_active).offset(skip).limit(limit).all()

# Create an instance for importing in other modules
item = CRUDItem(Item)